@@ -1,9 +1,12 @@
 """Test logger names."""
-from ajilog import logger
+from io import StringIO
+
+from .conf import import_ajilog
 
 
 def test_names():
     """Test if logger name conform to script name."""
-    logger.stream.truncate(0)
+    logger = import_ajilog().logger
+    logger.stream = StringIO()
     logger.debug(u'')
     assert __file__.split('/')[-1].split('.py')[0] in logger.stream.getvalue()
